@@ -1,10 +1,10 @@
-#' VN Dependence
+#' NNS Dependence
 #'
 #' Returns the dependence between two variables based on higher order partial moment correlations measured by frequency or area.
 #'
 #' @param x Variable 1
 #' @param y Variable 2
-#' @param order Controls the level of quadrant partitioning.  Defualts to \code{order=2}.  Errors can generally be rectified by setting \code{order=1}.
+#' @param order Controls the level of quadrant partitioning.  Default to \code{order=2}.  Errors can generally be rectified by setting \code{order=1}.
 #' @param degree Defaults to NULL to allow number of observations to be \code{degree} determinant.
 #' @param print.map  Plots quadrant means.  Defaults to FALSE.
 #' @return Returns the \code{"Correlation"} and \code{"Dependence"}
@@ -15,10 +15,10 @@
 #' @examples
 #' set.seed(123)
 #' x<-rnorm(100); y<-rnorm(100)
-#' VN.dep(x,y)
+#' NNS.dep(x,y)
 #' @export
 
-VN.dep = function( x, y,order = 2,
+NNS.dep = function( x, y,order = 2,
                    degree=NULL,
                    print.map=FALSE){
 
@@ -39,7 +39,7 @@ VN.dep = function( x, y,order = 2,
   dupm = numeric(0)
   cor.rhos = numeric(0)
   dep.rhos = numeric(0)
-
+  nonlin.cor = numeric(0)
 
 
   max.part = min(nchar(partitioned_df$quadrant))
@@ -58,25 +58,24 @@ VN.dep = function( x, y,order = 2,
     sub_x=prior.partitioned_df[prior.partitioned_df$quadrant == item,'x']
     sub_y=prior.partitioned_df[prior.partitioned_df$quadrant == item,'y']
 
+    weight=length(sub_x)/length(x)
+
       clpm = c(clpm, Co.LPM(degree,sub_x,sub_y))
       cupm = c(cupm, Co.UPM(degree,sub_x,sub_y))
       dlpm = c(dlpm, D.LPM(degree,degree,sub_x,sub_y))
       dupm = c(dupm, D.UPM(degree,degree,sub_x,sub_y))
+
+      dep.rhos =  c(dep.rhos,weight*abs((Co.LPM(degree,sub_x,sub_y)+Co.UPM(degree,sub_x,sub_y)-D.LPM(degree,degree,sub_x,sub_y)-D.UPM(degree,degree,sub_x,sub_y)) / (Co.LPM(degree,sub_x,sub_y)+Co.UPM(degree,sub_x,sub_y)+D.LPM(degree,degree,sub_x,sub_y)+D.UPM(degree,degree,sub_x,sub_y))))
+
+      nonlin.cor = c(nonlin.cor,weight*(Co.LPM(degree,sub_x,sub_y)+Co.UPM(degree,sub_x,sub_y)-D.LPM(degree,degree,sub_x,sub_y)-D.UPM(degree,degree,sub_x,sub_y)) / (Co.LPM(degree,sub_x,sub_y)+Co.UPM(degree,sub_x,sub_y)+D.LPM(degree,degree,sub_x,sub_y)+D.UPM(degree,degree,sub_x,sub_y)))
+
 }
 
-  dep.rhos =  abs((clpm+cupm-dlpm-dupm) / (clpm+cupm+dlpm+dupm))
-
-  m<- rbind((sum(clpm) +sum(cupm) -sum(dlpm) -sum(dupm))/(sum(clpm)+sum(cupm)+sum(dlpm)+sum(dupm)),
-
-            sum(na.omit(dep.rhos))/length(na.omit(dep.rhos)))
-
-  rownames(m) = c("Correlation","Dependence")
-
-  nonlin.cor = (sum(clpm) +sum(cupm) -sum(dlpm) -sum(dupm))/(sum(clpm)+sum(cupm)+sum(dlpm)+sum(dupm))
+  nonlin.cor = sum(na.omit(nonlin.cor))
 
   if(is.na(nonlin.cor)){nonlin.cor=0}
 
-  dep = sum(na.omit(dep.rhos))/length(na.omit(dep.rhos))
+  dep = sum(na.omit(dep.rhos))
 
   if(is.na(dep)){dep=0}
 
