@@ -4,12 +4,12 @@
 #'
 #' @param x Independent Variable
 #' @param y Dependent Variable
-#' @param order Controls the number of partial moment quadrant means.  Defaults to NULL to allow \link{VN.reg} to determine optimal order based on R2 of regression.  \code{order='max'} generates a more accurate derivative for well specified cases.
-#' @param s.t.n Signal to noise parameter, sets the threshold of \code{VN.dep} which reduces \code{"order"} when \code{order=NULL}.  Defaults to 0.9 to ensure high dependence for higher \code{"order"} and endpoint determination.
+#' @param order Controls the number of partial moment quadrant means.  Defaults to NULL to allow \link{NNS.reg} to determine optimal order based on R2 of regression.  \code{order='max'} generates a more accurate derivative for well specified cases.
+#' @param s.t.n Signal to noise parameter, sets the threshold of \code{NNS.dep} which reduces \code{"order"} when \code{order=NULL}.  Defaults to 0.9 to ensure high dependence for higher \code{"order"} and endpoint determination.
 #' @param eval.point Independent variable point to be evaluated.  Defaults to \code{median(x)}.
 #' @param deriv.order For second derivative estimate of \code{f(x)}, set \code{deriv.order=2}.  Defaults to first derivative.
 #' @param h Percentage step used for finite step method.  Defaults to \code{h=.05} representing a 5 percent step from the value of the independent variable.
-#' @param noise.reduction In low signal:noise situations, \code{noise.reduction="median"} uses medians instead of means for partitions, while \code{noise.reduction="mode"} uses modes instead of means for partitions.  \code{noise.reduction=NULL}  (Default setting) allows for maximum possible fit in \link{VN.reg}.
+#' @param noise.reduction In low signal:noise situations, \code{noise.reduction="median"} uses medians instead of means for partitions, while \code{noise.reduction="mode"} uses modes instead of means for partitions.  \code{noise.reduction=NULL}  (Default setting) allows for maximum possible fit in \link{NNS.reg}.
 #' @return Returns the value of the partial derivative estimate for the given order.
 #' @keywords partial derivative, nonlinear regression
 #' @author Fred Viole, OVVO Financial Systems
@@ -26,8 +26,8 @@ dy.dx <- function(x,y,order=NULL,s.t.n=0.9,eval.point=median(x),deriv.order=1,h=
   DV=y
 
   if(deriv.order==1){
-    reg.output <- VN.reg(IV,DV,plot = FALSE,return.values = TRUE,order=order,s.t.n = s.t.n,noise.reduction = noise.reduction)
-    xonly.output <- VN.reg(IV,DV,type="XONLY",plot=FALSE,return.values = TRUE,order = order,s.t.n = s.t.n,noise.reduction = noise.reduction)
+    reg.output <- NNS.reg(IV,DV,plot = FALSE,return.values = TRUE,order=order,s.t.n = s.t.n,noise.reduction = noise.reduction)
+    xonly.output <- NNS.reg(IV,DV,type="XONLY",plot=FALSE,return.values = TRUE,order = order,s.t.n = s.t.n,noise.reduction = noise.reduction)
 
 
       if(reg.output$R2 >= xonly.output$R2){
@@ -58,7 +58,7 @@ dy.dx <- function(x,y,order=NULL,s.t.n=0.9,eval.point=median(x),deriv.order=1,h=
     # f(x+h) - 2(f(x)) +f(x-h) / h^2
 
     deriv.points=matrix(c((1+h)*eval.point,eval.point,(1-h)*eval.point),ncol = length(eval.point),byrow = TRUE)
-    second.deriv.estimates= VN.reg(IV,DV,plot = FALSE,return.values = TRUE,order=order,point.est = deriv.points,s.t.n = s.t.n,noise.reduction = noise.reduction)$Point.est
+    second.deriv.estimates= NNS.reg(IV,DV,plot = FALSE,return.values = TRUE,order=order,point.est = deriv.points,s.t.n = s.t.n,noise.reduction = noise.reduction)$Point.est
     f.x_h = second.deriv.estimates[1]
 
     two_f.x = 2*second.deriv.estimates[2]
